<!-- markdownlint-disable MD024 -->

# Release notes

Starting from version 0.5.0, this format is based on [Keep a Changelog],
and this project adheres
to [Semantic Versioning]. Full commit history is available in the
[commit logs](https://github.com/Yoseflab/popv/commits/).

For the original manuscript version 0.4.0 was used. 0.5.0 is a
major rewrite of the project to scale
to several million cells on workstations with 128 GB of RAM
and enable more GPU-accelerated
functions.

## Version 0.5

### 0.5.2

#### Fixed

- Changed Louvain overclustering for Celltypist to Leiden.
- Fixed documentation references.
- Fix release workflow.

### 0.5.1

#### Fixed

- Fixed errors in Google Colab.

### 0.5.0

First major release. Production-ready code.

### 0.4.0

Version used for the manuscript.

[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html
